@@ -1,7 +1,11 @@
-from ._bot_package_path import _set_bot_package_path
+from .bot_package_path import _set_bot_package_path, get_bot_package_path
+
+BOT_VERSION = (2, 4, 6)
+_set_bot_package_path(__path__[0])
+
 from .arena import *
 from .channel import *
-from twitchbot.api.chatters import *
+from .api.chatters import *
 from .colors import *
 from .command import *
 from .config import *
@@ -30,6 +34,4 @@ from .poll import *
 from .event_util import *
 from .extra_configs import *
 from .pubsub import *
-
-BOT_VERSION = (2, 4, 5)
-_set_bot_package_path(__path__[0])
+from .translations import *
