@@ -8,7 +8,9 @@ from twitchbot import (
     session,
     cfg,
     Command,
-    InvalidArgumentsError)
+    InvalidArgumentsError,
+    translate
+)
 
 PERMISSION = 'manage_commands'
 
@@ -27,70 +29,70 @@ def _verify_resp_is_valid(resp: str):
               '%channel : the channels name')
 async def cmd_add_custom_command(msg: Message, *args):
     if len(args) < 2:
-        raise InvalidArgumentsError(reason='missing required arguments', cmd=cmd_add_custom_command)
+        raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_add_custom_command)
 
     name, resp = args[0], ' '.join(args[1:])
     name = name.lower()
 
     if not _verify_resp_is_valid(resp):
-        raise InvalidArgumentsError(reason='response cannot have . or / as the starting character',
+        raise InvalidArgumentsError(reason=translate('add_cmd_invalid_response'),
                                     cmd=cmd_add_custom_command)
 
     if custom_command_exist(msg.channel_name, name):
-        raise InvalidArgumentsError(reason='custom command already exist by that name',
+        raise InvalidArgumentsError(reason=translate('add_cmd_duplicate'),
                                     cmd=cmd_add_custom_command)
 
     if add_custom_command(CustomCommand.create(msg.channel_name, name, resp)):
-        await msg.reply(f'successfully added command "{name}", trigger the command using "{name}" (without the quotes)')
+        await msg.reply(translate('add_cmd_success', name=name))
     else:
-        await msg.reply('failed to add command')
+        await msg.reply(translate('add_cmd_fail', name=name))
 
 
 @Command('updatecmd', permission=PERMISSION, syntax='<name> <response>',
          help="updates a custom command's response message")
 async def cmd_update_custom_command(msg: Message, *args):
     if len(args) < 2:
-        raise InvalidArgumentsError(reason='missing required arguments', cmd=cmd_update_custom_command)
+        raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_update_custom_command)
 
     name, resp = args[0], ' '.join(args[1:])
     name = name.lower()
 
     if not _verify_resp_is_valid(resp):
-        raise InvalidArgumentsError(reason='response cannot have . or / as the starting character',
+        raise InvalidArgumentsError(reason=translate('add_cmd_invalid_response'),
                                     cmd=cmd_update_custom_command)
 
     cmd = get_custom_command(msg.channel_name, name)
     if cmd is None:
-        raise InvalidArgumentsError(reason=f'custom command "{name}" does not exist', cmd=cmd_update_custom_command)
+        raise InvalidArgumentsError(reason=translate('update_cmd_not_exists', name=name), cmd=cmd_update_custom_command)
 
     cmd.response = resp
     session.commit()
 
-    await msg.reply(f'successfully updated {cmd.name}')
+    await msg.reply(translate('update_cmd_success', name=name))
 
 
 @Command('delcmd', permission=PERMISSION, syntax='<name>', help='deletes a custom commands')
 async def cmd_del_custom_command(msg: Message, *args):
     if not args:
-        raise InvalidArgumentsError(reason='missing required arguments', cmd=cmd_del_custom_command)
+        raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_del_custom_command)
 
     cmd = get_custom_command(msg.channel_name, args[0].lower())
     if cmd is None:
-        raise InvalidArgumentsError(reason=f'no command found for "{args[0]}"', cmd=cmd_del_custom_command)
+        raise InvalidArgumentsError(reason=translate('update_cmd_not_exists', name=args[0]), cmd=cmd_del_custom_command)
 
     if delete_custom_command(msg.channel_name, cmd.name):
-        await msg.reply(f'successfully deleted command {cmd.name}')
+        await msg.reply(translate('del_cmd_success', name=args[0]))
     else:
-        await msg.reply(f'failed to delete command {cmd.name}')
+        await msg.reply(translate('del_cmd_fail', name=args[0]))
 
 
 @Command('cmd', syntax='<name>', help='gets a custom commmands response')
 async def cmd_get_custom_command(msg: Message, *args):
     if not args:
-        raise InvalidArgumentsError(reason='missing required arguments', cmd=cmd_get_custom_command)
+        raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_get_custom_command)
 
     cmd = get_custom_command(msg.channel_name, args[0].lower())
     if cmd is None:
-        raise InvalidArgumentsError(reason=f'no command found for "{args[0]}"', cmd=cmd_get_custom_command)
+        raise InvalidArgumentsError(reason=translate('update_cmd_not_exists', name=args[0]), cmd=cmd_get_custom_command)
 
-    await msg.reply(f'the response for "{cmd.name}" is "{cmd.response}"')
+    await msg.reply(translate('cmd_cmd_result', name=cmd.name, response=cmd.response))
